@@ -38,3 +38,5 @@ void brick_draw( SDL_Surface *surf, int map_x, int map_y, int shadow );
 /* handle a received brick action */
 void client_handle_brick_hit( BrickHit *hit );
 
+/* redraw all bricks */
+void client_redraw_all_bricks();
