@@ -111,7 +111,7 @@ void client_disconnect()
 	
 	/* disconnect */
 	socket_print_stats( &client );
-	sprintf( buf, "disconnected from %s", 
+	sprintf( buf, _("disconnected from %s"), 
 		 net_addr_to_string(&client.remote_addr) );
 	client_add_chatter( buf, 1 );
 	buf[0] = MSG_DISCONNECT;
@@ -146,9 +146,9 @@ void client_connect( GuiWidget *widget, GuiEvent *event )
 	
 	/* extract ip and port and build a new socket out of it */
 	gui_edit_get_text( edit_server, server, 128, 0, -1 );
-	snprintf( config.server, 64, server );
+	snprintf( config.server, 64, "%s", server );
 	if ( !net_build_addr( &newaddr, server, 0 ) ) {
-		client_printf_chatter( 1, "ERROR: address %s does not resolve", config.server );
+		client_printf_chatter( 1, _("ERROR: address %s does not resolve"), config.server );
 		return;
 	}
 	socket_init( &client, &newaddr );
@@ -162,12 +162,12 @@ void client_connect( GuiWidget *widget, GuiEvent *event )
 	msg_write_int8( MSG_CONNECT );
 	msg_write_int8( PROTOCOL );
 	msg_write_string( config.username );
-	msg_write_string( "unused" ); /* passwd */
+	msg_write_string( _("unused") ); /* passwd */
 	
 	while ( attempt < 3 ) {
 		client_printf_chatter( 1, "%s: %s...", 
 			config.server, 
-			attempt==0?"connecting":"retry" );
+			attempt==0?_("connecting"):_("retry") );
 		stk_display_update( STK_UPDATE_ALL );
 		net_transmit_connectionless( &newaddr, msglen, msgbuf );
 
@@ -185,11 +185,11 @@ void client_connect( GuiWidget *widget, GuiEvent *event )
 				case MSG_LOGIN_OKAY:
 					client_id = msg_read_int32();
 					strcpy( client_name, msg_read_string() );
-					client_printf_chatter( 1, "%s: connected!", config.server );
+					client_printf_chatter( 1, _("%s: connected!"), config.server );
 					client_is_connected = 1;
 					return;
 				case MSG_ERROR:
-					client_printf_chatter( 1, "ERROR: connection refused: %s",
+					client_printf_chatter( 1, _("ERROR: connection refused: %s"),
 						msg_read_string() );
 					return;
 			}
@@ -197,7 +197,7 @@ void client_connect( GuiWidget *widget, GuiEvent *event )
 		
 		attempt++;
 	}
-	client_add_chatter( "ERROR: server does not respond", 1 );
+	client_add_chatter( _("ERROR: server does not respond"), 1 );
 #endif
 }
 
@@ -319,7 +319,7 @@ void client_whisper_chatter(
 		gui_edit_set_text( edit_chatter, "" );
 	}
 	else
-		client_add_chatter( "You must select a user to whisper!", 1 );
+		client_add_chatter( _("You must select a user to whisper!"), 1 );
 #endif
 }
 
@@ -405,15 +405,15 @@ void client_challenge( GuiWidget *widget, GuiEvent *event )
 	
 	/* everything valid? */
 	if ( client_user == 0 ) {
-		client_popup_info( "You must select a user for a challenge." );
+		client_popup_info( _("You must select a user for a challenge.") );
 		return;
 	}
 	if ( client_levelset == 0 ) {
-		client_popup_info( "You must select a levelset for a challenge." );
+		client_popup_info( _("You must select a levelset for a challenge.") );
 		return;
 	}
 	if ( client_user->id == client_id ) {
-		client_popup_info( "You can't challenge yourself." );
+		client_popup_info( _("You can't challenge yourself.") );
 		return;
 	}
 	
@@ -436,7 +436,7 @@ void client_challenge( GuiWidget *widget, GuiEvent *event )
 	msg_write_int8( mp_balls );
 	client_transmit( CODE_BLUE, msglen, msgbuf );
 	
-	client_popup_info( "You have challenged %s. Let's see what (s)he says...", mp_peer_name );
+	client_popup_info( _("You have challenged %s. Let's see what (s)he says..."), mp_peer_name );
 	client_state = CLIENT_AWAIT_ANSWER;
 #endif
 }
@@ -545,7 +545,7 @@ void client_close_stats( GuiWidget *widget, GuiEvent *event )
 	if ( event->type != GUI_CLICKED ) return;
 	gui_widget_hide( dlg_stats );
 	client_state = CLIENT_NONE;
-	gui_label_set_text( label_stats, "Awaiting stats..." );
+	gui_label_set_text( label_stats, _("Awaiting stats...") );
 	gui_label_set_text( label_winner, "..." );
 }
 
