@@ -98,8 +98,6 @@ int gameSeed = 0; /* last used seed for freakout game */
 extern int current_player;
 extern Item *item_resume_0;
 
-extern void select_chart( char *name, int update );
-
 /*
 ====================================================================
 Locals
@@ -138,9 +136,9 @@ static int init_level( Player *player, int l_pos )
 
 	/* add&create background */
 	if ( game->game_type == GT_LOCAL )
-		bkgnd_draw( bkgnd, bkgnd_ids[player->level_id] );
+		bkgnd_draw( bkgnd, bkgnd_ids[player->level_id], 1 );
 	else
-		bkgnd_draw( bkgnd, -1 );
+		bkgnd_draw( bkgnd, -1, 1 );
 	/* add frame */
 	frame_draw();
 	/* add bricks */
@@ -939,7 +937,7 @@ void client_game_delete()
 /* create network/local game context and initiate game state:
  * network needs to receive the level data and a local game
  * has to load the next level */
-int client_game_init_local( char *setname )
+int client_game_init_local( const char *setname )
 {
         Set_Chart *chart;
 	int i, warp_limit;
@@ -1205,7 +1203,6 @@ void client_game_run( void )
 			if ( button_clicked || key_pressed ) {
 				chart_load();
 				check_highscores();
-				select_chart( game_set->name, 0 );
                                 /* remove saved game */
                                 slot_delete( 0 );
                                 slot_update_hint( 0, item_resume_0->hint );
@@ -1445,7 +1442,6 @@ void client_game_run( void )
 						 * high scores ***
 						if ( game_set ) {
 							check_highscores();
-							select_chart( game_set->name, 0 );
 						}*/
                         /* save local game */
                         if ( game_set != 0 /*not testing a level*/ )
