@@ -52,6 +52,17 @@ Global definitions for LBreakout and general system includes.
 #define CONFIG_DIR_NAME ".lgames"
 #endif
 
+/* i18n */
+#ifdef HAVE_CONFIG_H
+#include "../config.h"
+#endif
+#include "../common/gettext.h"
+#if ENABLE_NLS
+#define _(str) gettext (str)
+#else
+#define _(str) (str)
+#endif
+
 /*
 ====================================================================
 Alpha of shadow
@@ -69,4 +80,10 @@ enum { ORIG_BACK_COUNT = 6 };
 extern char msgbuf[MAX_MSG_SIZE];
 extern int msglen;
 
+/* check if position is in given region */
+#define FOCUS( cx, cy, rx, ry, rw, rh ) \
+	( cx >= rx && cy >= ry && cx < rx + rw && cy < ry + rh )
+#define FOCUS_RECT( cx, cy, rect ) \
+	FOCUS( cx, cy, (rect).x, (rect).y, (rect).w, (rect).h )
+
 #endif
