@@ -105,7 +105,7 @@ static SDL_Surface *IMG_LoadPNG_RW(SDL_RWops *src)
 	 * the normal method of doing things with libpng).  REQUIRED unless you
 	 * set up your own error handlers in png_create_read_struct() earlier.
 	 */
-	if ( setjmp(png_ptr->jmpbuf) ) {
+	if ( setjmp(png_jmpbuf(png_ptr)) ) {
 		IMG_SetError("Error reading the PNG file.");
 		goto done;
 	}
@@ -174,9 +174,9 @@ static SDL_Surface *IMG_LoadPNG_RW(SDL_RWops *src)
 			Rmask = 0x000000FF;
 			Gmask = 0x0000FF00;
 			Bmask = 0x00FF0000;
-			Amask = (info_ptr->channels == 4) ? 0xFF000000 : 0;
+			Amask = (png_get_channels(png_ptr, info_ptr) == 4) ? 0xFF000000 : 0;
 		} else {
-		        int s = (info_ptr->channels == 4) ? 0 : 8;
+		        int s = (png_get_channels(png_ptr, info_ptr) == 4) ? 0 : 8;
 			Rmask = 0xFF000000 >> s;
 			Gmask = 0x00FF0000 >> s;
 			Bmask = 0x0000FF00 >> s;
@@ -184,7 +184,7 @@ static SDL_Surface *IMG_LoadPNG_RW(SDL_RWops *src)
 		}
 	}
 	surface = SDL_AllocSurface(SDL_SWSURFACE, width, height,
-			bit_depth*info_ptr->channels, Rmask,Gmask,Bmask,Amask);
+			bit_depth*png_get_channels(png_ptr, info_ptr), Rmask,Gmask,Bmask,Amask);
 	if ( surface == NULL ) {
 		IMG_SetError("Out of memory");
 		goto done;
@@ -229,12 +229,18 @@ static SDL_Surface *IMG_LoadPNG_RW(SDL_RWops *src)
 		    palette->colors[i].g = i;
 		    palette->colors[i].b = i;
 		}
-	    } else if (info_ptr->num_palette > 0 ) {
-		palette->ncolors = info_ptr->num_palette; 
-		for( i=0; i<info_ptr->num_palette; ++i ) {
-		    palette->colors[i].b = info_ptr->palette[i].blue;
-		    palette->colors[i].g = info_ptr->palette[i].green;
-		    palette->colors[i].r = info_ptr->palette[i].red;
+	    } else {
+		png_colorp file_palette;
+		int file_num_palette;
+		png_get_PLTE(png_ptr, info_ptr, &file_palette,
+			     &file_num_palette);
+		if (file_num_palette > 0 ) {
+		    palette->ncolors = file_num_palette;
+		    for( i=0; i<file_num_palette; ++i ) {
+		        palette->colors[i].b = file_palette[i].blue;
+		        palette->colors[i].g = file_palette[i].green;
+		        palette->colors[i].r = file_palette[i].red;
+		    }
 		}
 	    }
 	}
@@ -1124,10 +1130,10 @@ contains 'b' for black 'w' for white and ' ' for transparent.
 SDL_Cursor* stk_cursor_create(
     int width, int height, int hot_x, int hot_y, char *source )
 {
-    char *mask = 0, *data = 0;
+    unsigned char *mask = 0, *data = 0;
     SDL_Cursor *cursor = 0;
     int i, j, k;
-    char data_byte, mask_byte;
+    unsigned char data_byte, mask_byte;
     int pot;
     /* create mask&data */
     mask = calloc( width * height / 8, sizeof ( char ) );
@@ -1419,14 +1425,14 @@ void stk_sound_play( StkSound *sound )
         channel = sound->channel;
         if ( channel == -1 )
             channel = Mix_GroupAvailable(-1);
-        Mix_Volume( channel, sound->volume );
+        Mix_Volume( channel, stk_audio_sound_volume );
         Mix_PlayChannel( channel, sound->chunk, 0 );
     }
 #endif
 }
 /*
 ====================================================================
-Play a sound at horizontal position x..
+Play a sound at horizontal position x.
 ====================================================================
 */
 void stk_sound_play_x( int x, StkSound *sound )
@@ -1442,6 +1448,7 @@ void stk_sound_play_x( int x, StkSound *sound )
         if ( channel == -1 )
             channel = Mix_GroupAvailable(-1);
         Mix_SetPanning( channel, 255 - x, x );
+        Mix_Volume( channel, stk_audio_sound_volume );
         Mix_PlayChannel( channel, sound->chunk, 0 );
     }
 #endif
