@@ -36,6 +36,14 @@
 #include "../common/parser.h"
 #include "../game/game.h"
 
+/* i18n */
+#include "../common/gettext.h"
+#if ENABLE_NLS
+#define _(str) gettext (str)
+#else
+#define _(str) (str)
+#endif
+
 /***** TYPE DEFINITIONS ****************************************************/
 
 typedef struct {
@@ -111,4 +119,3 @@ typedef struct {
 /***** PUBLIC FUNCTIONS ****************************************************/
 
 #endif
-
